@@ -1197,7 +1197,12 @@ main(int argc, char **argv)
 	switch (getopt_ret) {
 	case 'h': {
 	    cout << PROG_NAME" - "PROG_DESC"\n\n"
-"Usage: "PROG_NAME" [OPTIONS] --db DATABASE [BASEDIR] DIRECTORY\n\n"
+"Usage: "PROG_NAME" [OPTIONS] --db DATABASE [BASEDIR] DIRECTORY\n"
+"\n"
+"DIRECTORY is the directory to start indexing from.\n"
+"\n"
+"BASEDIR is the directory corresponding to URL (default: DIRECTORY).\n"
+"\n"
 "Options:\n"
 "  -d, --duplicates         set duplicate handling ('ignore' or 'replace')\n"
 "  -p, --no-delete          skip the deletion of documents corresponding to\n"
@@ -1206,8 +1211,8 @@ main(int argc, char **argv)
 "  -e, --empty-docs=ARG     how to handle documents we extract no text from:\n"
 "                           ARG can be index, warn (issue a diagnostic and\n"
 "                           index), or skip.  (default: warn)\n"
-"  -D, --db                 path to database to use\n"
-"  -U, --url                base url DIRECTORY represents (default: /)\n"
+"  -D, --db=DATABASE        path to database to use\n"
+"  -U, --url=URL            base url BASEDIR corresponds to (default: /)\n"
 "  -M, --mime-type=EXT:TYPE map file extension EXT to MIME Content-Type TYPE\n"
 "                           (empty TYPE removes any MIME mapping for EXT)\n"
 "  -F, --filter=TYPE:CMD    process files with MIME Content-Type TYPE using\n"
